pub struct EodDataItem {}Expand description
Rust representation of single data item from Marketstack eod response.
Fields
date: DateTime<Utc>Exact date/time the given data was collected in ISO-8601 format.
symbol: StringStock ticker symbol of the current data object.
exchange: StringExchange MIC identification associated with the current data object.
split_factor: f64Split factor used to adjust prices when a company splits, reverse splits or pays a distribution.
dividend: f64Distribution of earnings to shareholders.
open: f64Raw opening price of the given stock ticker.
high: f64Raw high price of the given stock ticker.
low: f64Raw low price of the given stock ticker.
close: f64Raw closing price of the given stock ticker.
volume: f64Raw volume of the given stock ticker.
adj_open: f64Adjusted opening price of the given stock ticker.
adj_high: f64Adjusted high price of the given stock ticker.
adj_low: f64Adjusted low price of the given stock ticker.
adj_close: f64Adjusted closing price of the given stock ticker.
adj_volume: f64Adjusted volume of the given stock ticker.